*******************************************
:mod:`gruvi.http` -- HTTP Client and Server
*******************************************

.. currentmodule:: gruvi.http

.. automodule:: gruvi.http
   :members:

   .. autodata:: REQUEST
      :annotation:

   .. autodata:: RESPONSE
      :annotation:

Example
=======

.. literalinclude:: ../examples/httpcs.py
   :language: python
